@@ -25,6 +25,14 @@ from .. import kerberos as ciecplib_kerberos
 
 __author__ = "Duncan Macleod <duncan.macleod@ligo.org>"
 
+KLIST_OUTPUT = b"""
+Ticket cache: API:krb5cc
+Default principal: test.user@REALM.ORG
+
+Valid starting       Expires              Service principal
+01/01/2021 00:00:01  02/01/2021 00:00:01  krbtgt/REALM.ORG@REALM.ORG
+""".strip()
+
 
 @pytest.mark.parametrize("side_effect, result", [
     (None, True),
@@ -34,3 +42,15 @@ __author__ = "Duncan Macleod <duncan.macleod@ligo.org>"
 def test_has_credential(mock_output, side_effect, result):
     mock_output.side_effect = side_effect
     assert ciecplib_kerberos.has_credential("klist") is result
+
+
+@mock.patch("subprocess.check_output", return_value=KLIST_OUTPUT)
+def test_find_principal(_):
+    assert ciecplib_kerberos.find_principal("klist") == "test.user@REALM.ORG"
+
+
+@mock.patch("subprocess.check_output", return_value=b"")
+def test_find_principal_error(_):
+    with pytest.raises(RuntimeError) as exc:
+        ciecplib_kerberos.find_principal("klist")
+    assert str(exc.value) == "failed to parse principal from `klist` output"
